@@ -213,7 +213,7 @@ class ConfigDialog(QtGui.QDialog):
         #: (:obj:`str`) security stream port
         self.secport = "5657"
         #: (:obj:`str`) hidra data port
-        self.hidraport = "50001"
+        self.hidraport = '["50001"]'
         #: (:obj:`bool`) find security stream port automatically
         self.secautoport = True
         #: (:obj:`float`) refresh rate
@@ -249,8 +249,12 @@ class ConfigDialog(QtGui.QDialog):
 
         #: (:obj:`bool`) show bakcground subtraction widget
         self.showsub = True
-        #: (:obj:`bool`) show bakcground subtraction scaling widget
+        #: (:obj:`bool`) show bakcground subtraction scaling factor widget
         self.showsubsf = False
+        #: (:obj:`bool`) show image normalization widget
+        self.shownorm = True
+        #: (:obj:`bool`) show image normalization scaling factor widget
+        self.shownormsf = False
         #: (:obj:`bool`) show transformation widget
         self.showtrans = True
         #: (:obj:`bool`) show memory buffer widget
@@ -454,6 +458,8 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.secautoportCheckBox.setChecked(self.secautoport)
         self.__ui.secportLineEdit.setText(self.secport)
         self.__ui.hidraportLineEdit.setText(self.hidraport)
+        self.__ui.hidraportLineEdit.setText(
+            " ".join(json.loads(self.hidraport)))
         self.__ui.mbufsizeLineEdit.setText(self.maxmbuffersize)
         self.__ui.showhistoCheckBox.setChecked(self.showhisto)
         self.__ui.showaddhistoCheckBox.setChecked(self.showaddhisto)
@@ -463,7 +469,9 @@ class ConfigDialog(QtGui.QDialog):
         self.__ui.showstepsCheckBox.setChecked(self.showsteps)
         self.__ui.calcvarianceCheckBox.setChecked(self.calcvariance)
         self.__ui.showsubCheckBox.setChecked(self.showsub)
+        self.__ui.shownormCheckBox.setChecked(self.shownorm)
         self.__ui.showsubsfCheckBox.setChecked(self.showsubsf)
+        self.__ui.shownormsfCheckBox.setChecked(self.shownormsf)
         self.__ui.showtransCheckBox.setChecked(self.showtrans)
         self.__ui.showmbufferCheckBox.setChecked(self.showmbuffer)
         self.__ui.showrangeCheckBox.setChecked(self.showrange)
@@ -780,7 +788,9 @@ class ConfigDialog(QtGui.QDialog):
         self.diffnpt = int(
             self.__ui.diffsizeSpinBox.value())
         self.showsub = self.__ui.showsubCheckBox.isChecked()
+        self.shownorm = self.__ui.shownormCheckBox.isChecked()
         self.showsubsf = self.__ui.showsubsfCheckBox.isChecked()
+        self.shownormsf = self.__ui.shownormsfCheckBox.isChecked()
         self.showtrans = self.__ui.showtransCheckBox.isChecked()
         self.showmbuffer = self.__ui.showmbufferCheckBox.isChecked()
         self.showrange = self.__ui.showrangeCheckBox.isChecked()
@@ -970,8 +980,11 @@ class ConfigDialog(QtGui.QDialog):
             self.__ui.secportLineEdit.setFocus(True)
             return
         try:
-            self.hidraport = str(self.__ui.hidraportLineEdit.text()).strip()
-            int(self.hidraport)
+            hidraport = str(
+                self.__ui.hidraportLineEdit.text()).strip().split(" ")
+            for pt in hidraport:
+                int(pt)
+            self.hidraport = json.dumps([pt for pt in hidraport if pt])
         except Exception:
             self.__ui.tabWidget.setCurrentIndex(2)
             self.__ui.hidraportLineEdit.setFocus(True)
