@@ -559,23 +559,27 @@ class ImageDisplayWidget(_pg.GraphicsLayoutWidget):
                 else:
                     self._hideimages()
                     self.__image.show()
-                    self.__image.setLookupTable(None)
+                    # if uncomented the gradientColors does not work
+                    # self.__image.setLookupTable(None)
                     if img.dtype.kind == 'f' and np.isnan(img.min()):
                         img = np.nan_to_num(img)
                     if self.__channellevels and self.levelMode() != 'mono':
                         self.__image.setImage(
-                            img, lut=None,
+                            img,
+                            # lut=None,
                             levels=self.__channellevels,
                             autoLevels=False)
                     elif self.__displaylevels[0] is not None \
                             and self.__displaylevels[1] is not None:
                         self.__image.setImage(
-                            img, lut=None,
+                            img,
+                            # lut=None,
                             levels=self.__displaylevels,
                             autoLevels=False)
                     else:
                         self.__image.setImage(
-                            img, lut=None,
+                            img,
+                            # lut=None,
                             # levels=[[0,255], [0, 255], [0, 255]],
                             autoLevels=False)
             elif (self.__autodisplaylevels
