@@ -38,13 +38,13 @@ from . import filewriter
 if sys.version_info > (3,):
     long = int
 
-
 try:
     import fabio
     #: (:obj:`bool`) fabio can be imported
     FABIO = True
 except ImportError:
     FABIO = False
+
 try:
     import PIL
     import PIL.Image
@@ -441,6 +441,8 @@ class ImageFileHandler(object):
             if FABIO:
                 self.__image = fabio.open(fname)
                 self.__data = self.__image.data
+                if self.__data is None:
+                    raise Exception("no data")
                 if "_array_data.header_convention" \
                    in self.__image.header.keys():
                     rmeta = self.__image.header["_array_data.header_contents"]
@@ -504,15 +506,21 @@ class CBFLoader(object):
         mdata = {}
         try:
             if hasattr(flbuffer, "tostring"):
-                hspos = flbuffer.tostring().index(headerstart) // \
-                    flbuffer.itemsize
+                try:
+                    hspos = flbuffer.tostring().index(headerstart) // \
+                        flbuffer.itemsize
+                except Exception:
+                    hspos = 0
                 hepos = flbuffer.tostring().index(headerend) // \
                     flbuffer.itemsize
                 flbuffer = flbuffer[hspos:hepos + 1].tostring()
         except Exception as e:
             # print(str(e))
             logger.warning(str(e))
-        header = str(flbuffer).strip()
+        try:
+            header = str(flbuffer, "utf8").strip()
+        except Exception:
+            header = str(flbuffer).strip()
         sheader = [hd[2:] for hd in str(header).split("\r\n")
                    if hd.startswith("# ")]
 
