@@ -622,6 +622,22 @@ class TangoFileSource(BaseSource):
             if self.__dproxy:
                 dattr = self.__dproxy.read().value
                 filename = "%s/%s" % (dattr, filename)
+            for sm in self.__schema:
+                if filename.startswith(sm):
+                    filename = filename[(len(sm) - 1):]
+                    scheme = "file"
+                    break
+            if not scheme:
+                for sm in self.__schema:
+                    if filename.startswith("h5" + sm):
+                        filename = filename[(len(sm) + 1):]
+                        scheme = "h5file"
+                        break
+            if not scheme:
+                for sm in ("http://", "https://"):
+                    if filename.startswith(sm):
+                        scheme = "httplink"
+                        break
             for key, val in self.__dirtrans.items():
                 filename = filename.replace(key, val)
             if str(filename) in ["", "/"]:
@@ -688,7 +704,10 @@ class TangoFileSource(BaseSource):
                         self.__nxsfile, self.__nxsfield, self.__frame)
                     self.__frame += 1
                     return (np.transpose(image), '%s' % (filename), metadata)
-
+            elif scheme in ["httplink"]:
+                httpSource = HTTPSource()
+                httpSource.setConfiguration(filename)
+                return httpSource.getData()
             else:
                 self.__resetnexus()
                 fh = imageFileHandler.ImageFileHandler(str(filename))
@@ -2215,6 +2234,7 @@ class HiDRASource(BaseSource):
             sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             result = sock.connect_ex(
                 (self.__targetname, int(self.__portnumber)))
+            sock.close()
             if result:
                 self._configuration = configuration
                 self.__target = [
