@@ -77,8 +77,12 @@ class Settings(object):
         self.calcvariance = False
         #: (:obj:`bool`) show bakcground subtraction widget
         self.showsub = True
-        #: (:obj:`bool`) show bakcground subtraction scaling widget
+        #: (:obj:`bool`) show image normalization widget
+        self.shownorm = True
+        #: (:obj:`bool`) show bakcground subtraction scaling factor widget
         self.showsubsf = False
+        #: (:obj:`bool`) show image normalization scaling factor widget
+        self.shownormsf = False
         #: (:obj:`bool`) show transformation widget
         self.showtrans = True
         #: (:obj:`bool`) show memory buffer widget
@@ -108,7 +112,7 @@ class Settings(object):
         #: (:obj:`str`) security stream port
         self.secport = "5657"
         #: (:obj:`str`) hidra data port
-        self.hidraport = "50001"
+        self.hidraport = '["50001"]'
         #: (:obj:`str`) maximal number of images in memory buffer
         self.maxmbuffersize = "1000"
         #: (:obj:`int`) number of image sources
@@ -395,10 +399,18 @@ class Settings(object):
             "Configuration/ShowSubtraction", type=str))
         if qstval.lower() == "false":
             self.showsub = False
+        qstval = str(settings.value(
+            "Configuration/ShowNormalization", type=str))
+        if qstval.lower() == "false":
+            self.shownorm = False
         qstval = str(settings.value(
             "Configuration/ShowSubtractionScaling", type=str))
         if qstval.lower() == "true":
             self.showsubsf = True
+        qstval = str(settings.value(
+            "Configuration/ShowNormalizationScaling", type=str))
+        if qstval.lower() == "true":
+            self.shownormsf = True
         qstval = str(settings.value(
             "Configuration/ShowTransformations", type=str))
         if qstval.lower() == "false":
@@ -501,12 +513,25 @@ class Settings(object):
             self.secport = str(qstval)
         except Exception:
             pass
+
         qstval = str(settings.value("Configuration/HidraDataPort", type=str))
-        try:
-            int(qstval)
-            self.hidraport = str(qstval)
-        except Exception:
-            pass
+        if qstval.startswith("["):
+            try:
+                ports = json.loads(qstval)
+                for port in ports:
+                    int(port)
+                self.hidraport = qstval
+            except Exception:
+                for port in qstval:
+                    int(port)
+                self.hidraport = json.dumps([str(tp) for tp in qstval])
+        else:
+            try:
+                int(qstval)
+                self.hidraport = json.dumps([str(qstval)])
+            except Exception:
+                pass
+
         qstval = str(settings.value("Configuration/MaxBufferSize", type=str))
         try:
             self.maxmbuffersize = str(qstval)
@@ -915,9 +940,15 @@ class Settings(object):
         settings.setValue(
             "Configuration/ShowSubtraction",
             self.showsub)
+        settings.setValue(
+            "Configuration/ShowNormalization",
+            self.shownorm)
         settings.setValue(
             "Configuration/ShowSubtractionScaling",
             self.showsubsf)
+        settings.setValue(
+            "Configuration/ShowNormalizationScaling",
+            self.shownormsf)
         settings.setValue(
             "Configuration/ShowTransformations",
             self.showtrans)
